@@ -41,7 +41,7 @@ bool Bayonne::shutdown_flag = false;
 time_t Bayonne::start_time = 0;
 AtomicCounter Bayonne::libexec_count = 0;
 unsigned Bayonne::compile_count;
-
+volatile bool Bayonne::image_loaded = false;
 
 Audio::Encoding Bayonne::peer_encoding = Audio::unknownEncoding;
 Audio::timeout_t Bayonne::peer_framing = 0;
@@ -83,6 +83,15 @@ Bayonne::statetab Bayonne::states[] = {
 	{"final", &BayonneSession::stateFinal, ' '},
 	{NULL, NULL, ' '}};
 
+void Bayonne::waitLoaded(void)
+{
+	while(!image_loaded)
+	{
+		Thread::sleep(100);
+		Thread::yield();
+	}
+}
+
 bool Bayonne::loadPlugin(const char *prefix, const char *path)
 {
         char pathbuf[256];
@@ -562,6 +571,8 @@ compile:
 
 	img->commit();
 	lock.leave();
+	if(compile_count)
+		image_loaded = true;
 	return img;
 }
 
@@ -602,7 +613,7 @@ ScriptImage *Bayonne::useImage(void)
 {
 	ScriptImage *img;
 
-	if(!server)
+	if(!server || !image_loaded)
 		return NULL;
 
 	server->enter();
