@@ -108,6 +108,7 @@ public:
 	static timeout_t reset_timer;
 	static timeout_t exec_timer;
 	static unsigned compile_count;
+	static volatile bool image_loaded;
 
 	static BayonneDriver *start_driver;
 	static Audio::Encoding peer_encoding;
@@ -652,6 +653,11 @@ public:
 	 */	
 	static void allocate(timeslot_t timeslots, ScriptCommand *server = NULL);
 
+	/**
+	 * Wait for live flag...
+	 */
+	static void waitLoaded(void);
+	
 	/**
 	 * Get server uptime.
 	 *
