@@ -145,6 +145,49 @@ void BayonneSession::finalize(void)
 	slog.debug("%s: session stopping", logname);
 }
 
+const char *BayonneSession::getWritepath(char *buf, size_t len)
+{
+	char nbuf[128];
+	const char *cp, *ep;
+	const char *name = getValue(NULL);
+
+	const char *prefix = getKeyword("prefix");
+	if(!prefix || !*prefix)
+		prefix = NULL;
+
+	if(!name || !*name)
+		return NULL;
+
+	if(strchr(name, '/') || strchr(name, ':'))
+	{
+		cp = audio.getFilename(name, true);
+		goto finish;
+	}
+
+	if(!prefix)
+		return NULL;
+
+	ep = prefix + strlen(prefix) - 1;
+	if(*ep == ':' || *ep == '/')
+		snprintf(nbuf, sizeof(nbuf), "%s%s", prefix, name);
+	else
+		snprintf(nbuf, sizeof(nbuf), "%s/%s", prefix, name);
+
+	cp = audio.getFilename(nbuf, true);
+finish:
+	if(!cp)
+		return NULL;
+
+	if(!buf || !len)
+		return cp;
+
+	if(*cp == '/' || cp[1] == ':')
+		setString(buf, len, cp);
+	else
+		snprintf(buf, len, "%s/%s", server->getLast("prefix"), cp);
+	return buf;
+}
+	
 unsigned BayonneSession::getId(void)
 {
 	return (unsigned)timeslot;
@@ -675,6 +718,8 @@ Script::Name *BayonneSession::attachStart(Event *event)
 	if(!img)
 	{
 		img = useImage();
+		if(!img)
+			return NULL;
 		ref = true;
 	}
 
