@@ -968,6 +968,7 @@ exitkey:
                 }
 		break;
 	case AUDIO_IDLE:
+	case TIMER_EXPIRED:
 		if(setLibreset(RESULT_COMPLETE))
 			return true;
 
@@ -1076,6 +1077,7 @@ bool BayonneSession::stateJoin(Event *event)
 	const char *emsg;
 	event_t id;
 	bool rtn;
+	Event parting;
 
         if(enterJoin(event))
                 return true;
@@ -1110,7 +1112,11 @@ bool BayonneSession::stateJoin(Event *event)
 	rtn = enterCommon(event);
 	if(!isJoined())
 	{
-//		clrAudio();
+		memset(&parting, 0, sizeof(parting));
+		parting.id = PART_PEER;
+		if(!enterJoin(&parting) && !thread)
+			clrAudio();
+
 		switch(id)
 		{
 		case DTMF_KEYUP:
@@ -1132,7 +1138,9 @@ bool BayonneSession::stateJoin(Event *event)
 	return rtn;
 
 part:
-	if(!thread)
+	memset(&parting, 0, sizeof(parting));
+	parting.id = PART_PEER;
+	if(!enterJoin(&parting) && !thread)
 		clrAudio();	// get on other side of reset timer if thread
 
 	if(!scriptEvent(msg))
