@@ -36,8 +36,9 @@ static Keydata::Define driver[] = {
 	{"silence", "500"},
 	{"duration", "3600"},
 	{"pickup", "2000"},
+	{"hangup", "250"},
 	{"accept", "320"},
-	{"audio", "200"},
+	{"audio", "60"},
 	{"jitter", "2"},
 	{"filler", "false"},
 #ifdef	WIN32		// use localhost default if not in conf for w32
@@ -59,6 +60,7 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 {
 	const char *cp, *p;
 	char buf[1024];
+	AudioCodec *codec;
 
 #ifdef	WIN32
 	const char *env = Process::getEnv("DRIVERCONFIG");
@@ -76,11 +78,15 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 		cp = getLast("pickup");
 
 	if(cp)
-		pickup_timer = atoi(cp);
+		pickup_timer = atol(cp);
 
-	if(pickup_timer < 100)
+	if(pickup_timer < 10)
 		pickup_timer *= 1000;
 
+	cp = getLast("hangup");
+	if(cp)
+		hangup_timer = atol(cp);
+
 	cp = getLast("bind");
 	if(!cp)
 		cp = getLast("interface");
@@ -141,6 +147,7 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 
 
 	audio_timer = atol(getLast("audio"));
+	hangup_timer -= audio_timer;
 	accept_timer = atol(getLast("accept"));
 	jitter = atoi(getLast("jitter"));
 	data_payload = atoi(getLast("payload"));
@@ -168,6 +175,15 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 	registry = false;
 	silent_frame = new Sample[info.framecount];
 	memset(silent_frame, 0, info.framecount * 2);
+	silent_encoded = new unsigned char[info.framesize];
+	if(info.encoding == Audio::pcm16Mono)
+		memset(silent_encoded, 0, info.framesize);
+	else
+	{
+		codec = AudioCodec::getCodec(info);
+		codec->encode(silent_frame, silent_encoded, info.framecount);
+		AudioCodec::endCodec(codec);
+	}	
 }
 
 void Driver::startDriver(void)
@@ -528,6 +544,7 @@ void Driver::run(void)
 	char duration[10];
 	osip_body_t *mbody;
 
+	Bayonne::waitLoaded();
 	time(&last);
 
 	for(;;)
