@@ -116,8 +116,9 @@ void Session::makeIdle(void)
 
 bool Session::enterHangup(Event *event)
 {
-	if(event->id == ENTER_STATE)
+	if(event->id == TIMER_EXPIRED)
 	{
+		offhook = true;
 		sipHangup();
 		stopRTP();
 	}
@@ -151,6 +152,8 @@ bool Session::enterPlay(Event *event)
 	switch(event->id)
 	{
 	case AUDIO_IDLE:
+		if(!Driver::sip.audio_timer)
+			return false;
 		startTimer(Driver::sip.audio_timer);
 		return true;
 	case ENTER_STATE:
