@@ -20,6 +20,7 @@ class Libexec {
 	var $reply = 0;
 	var $resultcode = 0;
 	var $exitcode = 0;
+	var $level = 0;
 	var $version = "4.0";
 	var $tsession;
 	var $stdin;
@@ -286,6 +287,10 @@ class Libexec {
 		return true;
 	}
 
+	function set_level($level) {
+		$this->level = $level;
+	}
+
 	function replay_file($file) {
 		$file = get_filename($file);
 		if(strlen($file) < 1) {
@@ -331,6 +336,21 @@ class Libexec {
 		return $this->send_command("$voice $prompt");
 	}
 
+	function play_tone($tone, $duration) {
+		$level = $this->level;
+		return $this->send_command("TONE $tone $duration $level");
+	}
+
+        function single_tone($tone, $duration) {
+                $level = $this->level;
+                return $this->send_command("STONE $tone $duration $level");
+        }      
+
+        function dual_tone($tone1, $tone2, $duration) {
+                $level = $this->level;
+                return $this->send_command("DTONE $tone1 $tone2 $duration $level");
+        }      
+            
 	function read_input($count, $timeout) {
 		$result = $this->send_command("READ $timeout $count");
 		if($result == 0) {
@@ -339,7 +359,7 @@ class Libexec {
 		return "";
 	}
 
-	function key_input($timeout) {
+	function read_key($timeout) {
 		$result = $this->send_command("READ $timeout");
 		if($result == 0) {
 			return substr($this->digits, 0, 1);
