@@ -22,6 +22,32 @@ namespace server {
 using namespace ost;
 using namespace std;
 
+const char *Checks::chkPaths(Line *line, ScriptImage *img)
+{	
+	unsigned idx = 0;
+	const char *cp;
+
+	if(getMember(line))
+		return "paths do not use members";
+
+	if(!strnicmp(line->cmd, "read", 4))
+	{
+		if(!useKeywords(line, "=prefix=voice=extension"))
+			return "invalid keywords used for path";
+	}	
+	else if(!useKeywords(line, "=prefix=extension"))
+		return "invalid keywords used for path";
+
+	cp = getOption(line, &idx);
+	if(!cp || (*cp != '%' && *cp != '&'))
+		return "invalid or missing variable target";
+
+	if(!getOption(line, &idx))
+		return "missing path to evaluate";
+
+	return NULL;
+}
+
 const char *Checks::chkKey(Line *line, ScriptImage *img)
 {
 	if(getMember(line))
@@ -246,6 +272,7 @@ const char *Checks::chkDir(Line *line, ScriptImage *img)
 {
 	unsigned count = 0;
 	const char *cp;
+	char path[256];
 
 	if(getMember(line))
 		return "dir has no members";
@@ -270,7 +297,8 @@ const char *Checks::chkDir(Line *line, ScriptImage *img)
 		if(strchr(cp, ':'))
 			return "invalid directory name used";
 
-		Dir::create(cp);		
+		snprintf(path, sizeof(path), "%s/%s", keypaths.getLast("datafiles"), cp);
+		Dir::create(path);		
 	}
 	return "";
 }
