@@ -122,7 +122,7 @@ bool Methods::scrJoin(void)
 
 bool Methods::scrTransfer(void)
 {
-	char nbuf[256];
+	char nbuf[MAX_PATHNAME];
 	unsigned len = 0;
 	const char *cp;
 
@@ -150,7 +150,7 @@ bool Methods::scrTransfer(void)
 
 bool Methods::scrStart(void)
 {
-	char nbuf[256];
+	char nbuf[MAX_PATHNAME];
 	const char *name = getValue(NULL);
 	char *number = NULL;
 	unsigned len = 0;
@@ -1049,7 +1049,7 @@ bool Methods::scrErase(void)
 		return true;
 	}
 
-	cp = audio.getFilename(getValue(NULL), true);
+	cp = getWritepath();
 	if(!cp)
 	{
 		error("erase-invalid-file");
@@ -1065,6 +1065,7 @@ bool Methods::scrMove(void)
 	const char *cp = getAudio(false);
 	const char *dp;
 	const char *se, *de;
+	char buf1[MAX_PATHNAME], buf2[MAX_PATHNAME];
 	
 	if(cp)
 	{
@@ -1073,14 +1074,14 @@ bool Methods::scrMove(void)
 		return true;
 	}
 
-	cp = audio.getFilename(getValue(NULL), true);
+	cp = getWritepath(buf1, sizeof(buf1));
 	if(!cp)
 	{
 		error("invalid-source");
 		return true;
 	}
-	
-	dp = audio.getFilename(getValue(NULL), true);
+
+	dp = getWritepath(buf2, sizeof(buf2));	
 	if(!cp)
 	{
 		error("invalid-target");
@@ -1118,6 +1119,7 @@ bool Methods::scrCopy(void)
 	const char *cp = getAudio(false);
 	const char *dp;
 	const char *se, *de;
+	char buf1[MAX_PATHNAME], buf2[MAX_PATHNAME];
 	
 	if(cp)
 	{
@@ -1126,14 +1128,14 @@ bool Methods::scrCopy(void)
 		return true;
 	}
 
-	cp = audio.getFilename(getValue(NULL), true);
+	cp = getWritepath(buf1, sizeof(buf1));
 	if(!cp)
 	{
 		error("invalid-source");
 		return true;
 	}
-	
-	dp = audio.getFilename(getValue(NULL), true);
+
+	dp = getWritepath(buf2, sizeof(buf2));	
 	if(!cp)
 	{
 		error("invalid-target");
@@ -1161,8 +1163,9 @@ bool Methods::scrCopy(void)
 bool Methods::scrBuild(void)
 {
 	unsigned count = 0;
-	const char *cp;
+	const char *cp, *dp;
 	Audio::Info info;
+	char buf[MAX_PATHNAME];
 
 	cp = getAudio();
         if(cp)
@@ -1173,6 +1176,12 @@ bool Methods::scrBuild(void)
                 return true;
         }
 
+	dp = getWritepath(buf, sizeof(buf));
+	if(!dp)
+	{
+		error("missing target");
+		return true;
+	}
         cp = audio.translator->speak(this);
         if(cp)
         {
@@ -1189,7 +1198,7 @@ bool Methods::scrBuild(void)
 	if(info.rate == Audio::rateUnknown)
 		info.rate = Audio::rate8khz;
 
-	new BuildThread(dynamic_cast<ScriptInterp *>(this), &audio, &info, state.audio.list);
+	new BuildThread(dynamic_cast<ScriptInterp *>(this), &audio, &info, dp, state.audio.list);
 	return false;
 }
 
@@ -1402,6 +1411,163 @@ bool Methods::scrPlay(void)
 	return false;
 }
 
+bool Methods::scrPath(void)
+{
+	char fbuf[64];
+	const char *ep;
+	const char *prefix = getKeyword("prefix");
+	const char *cp = getAudio();
+	const char *ext;
+	Symbol *sym;
+
+	if(prefix && !*prefix)
+		prefix = NULL;
+
+	if(cp)
+	{
+                slog.error("%s: %s", logname, cp);
+                if(!signalScript(SIGNAL_FAIL))
+                        error("invalid-audio");
+                return true;
+        } 
+
+	cp = getOption(NULL);
+	if(!cp)
+	{
+nosym:
+		error("no-symbol");
+		return true;
+	}
+	sym = mapSymbol(cp, sizeof(fbuf));
+	if(!sym)
+		goto nosym;
+
+	cp = getValue(NULL);
+	if(!cp)
+	{
+		error("no-path");
+		return true;
+	}
+	ext = strrchr(cp, '/');
+	if(ext)
+		ext = strrchr(ext, '.');
+	else
+		ext = strchr(cp, '.');
+	if(ext)
+		ext = "";
+	else
+	{
+		ext = getKeyword("extension");
+		if(!ext || !*ext)
+			ext = audio.libext;
+	}
+
+	if(!strchr(cp, '/') && !strchr(cp, ':') && prefix)
+	{
+		ep = prefix + strlen(prefix) - 1;
+		if(*ep == '/' || *ep == ':')
+			snprintf(fbuf, sizeof(fbuf), "%s%s%s", prefix, cp, ext);
+		else
+			snprintf(fbuf, sizeof(fbuf), "%s/%s%s", prefix, cp, ext);
+		goto finish;
+	}
+
+	snprintf(fbuf, sizeof(fbuf), "%s%s", cp, ext);
+finish:
+	Bayonne::commit(sym, fbuf);
+	advance();
+	return true;
+}
+
+bool Methods::scrReadpath(void)
+{
+	char fbuf[MAX_PATHNAME];
+	const char *cp = getAudio();
+	Symbol *sym;
+
+	if(cp)
+	{
+                slog.error("%s: %s", logname, cp);
+                if(!signalScript(SIGNAL_FAIL))
+                        error("invalid-audio");
+		return true;
+	}
+
+	cp = getOption(NULL);
+	if(!cp)
+		goto nosym;
+
+	sym = mapSymbol(cp, sizeof(fbuf));
+
+	if(!sym)
+	{
+nosym:
+		error("no-symbol");
+		return true;
+	}
+	cp = getValue(NULL);
+	if(!cp || !*cp)
+		goto error;
+	cp = audio.getFilename(cp);
+	if(!cp)
+	{
+error:
+		error("invalid-path");
+		return true;
+	}
+	if(*cp != '/' && cp[1] != ':')
+	{
+		snprintf(fbuf, sizeof(fbuf), "%s/%s", keypaths.getLast("datafiles"));
+		cp = fbuf;
+	}
+	Bayonne::commit(sym, cp);
+	advance();
+	return true;
+}
+
+bool Methods::scrWritepath(void)
+{
+	char buf[MAX_PATHNAME];
+	char fbuf[MAX_PATHNAME];
+	const char *cp = getAudio();
+	Symbol *sym;
+
+	if(cp)
+	{
+                slog.error("%s: %s", logname, cp);
+                if(!signalScript(SIGNAL_FAIL))
+                        error("invalid-audio");
+		return true;
+	}
+
+	cp = getOption(NULL);
+	if(!cp)
+		goto nosym;
+	sym = mapSymbol(cp, sizeof(buf));
+
+	if(!sym)
+	{
+nosym:
+		error("no-symbol");
+		return true;
+	}
+	cp = getWritepath(buf, sizeof(buf));
+	if(!cp)
+	{
+		error("invalid-path");
+		return true;
+	}
+	if(*cp != '/' && cp[1] != ':')
+	{
+		snprintf(fbuf, sizeof(fbuf), "%s/%s", keypaths.getLast("datafiles"), cp);
+		cp = fbuf;
+	}
+	Bayonne::commit(sym, cp);
+	advance();
+	return true;
+}
+
+	
 bool Methods::scrPathname(void)
 {
 	unsigned count = 0;
