@@ -138,6 +138,8 @@ static void loading(void)
 	if(cp)
 		bs = atoi(cp) * 1024;
 
+	getcwd(buffer, sizeof(buffer));
+
 	BayonneSysexec::allocate(keypaths.getLast("libexec"), bs, pri,
 		keypaths.getLast("modexec"));
 #endif
@@ -226,6 +228,13 @@ start:
 #endif
 
 	Bayonne::reload();
+	if(!Bayonne::compile_count)
+	{
+		Bayonne::errlog("critical", "no applications defined");
+		stop(-1);
+	}
+	else
+		Bayonne::errlog("notice", "%d applications compiled", Bayonne::compile_count); 
 	BayonneService::start();
 	Bayonne::errlog("notice", "%s driver started; %d timeslot(s) used", dname, count);
 #ifndef	WIN32
@@ -350,6 +359,10 @@ static void testing(char **argv)
 	testConfig(*argv);		
 	if(!parseConfig(argv))
 		Script::exec_extensions = "";
+
+        Process::setScheduler(keyengine.getLast("scheduler"));
+        Process::setPriority(atoi(keyengine.getLast("priority"))); 
+
 	logging();
 
 	Bayonne::errlog("notice", "testing %s on %s %s; driver=%s, timeslots=%s",
@@ -380,6 +393,9 @@ int main(int argc, char **argv)
                 cerr << "use: bayonne --option [args...]" << endl;
                 exit(-1);
         }
+#ifdef	HAVE_LIBEXEC
+	BayonneSysexec::setArgv0(argv[0]);
+#endif
         cp = argv[1];
         if(!strncmp(cp, "--", 2))
                 ++cp;
