@@ -22,7 +22,7 @@ namespace server {
 using namespace ost;
 using namespace std;
 
-BuildThread::BuildThread(ScriptInterp *interp, BayonneAudio *au, Audio::Info *inf, const char **list) :
+BuildThread::BuildThread(ScriptInterp *interp, BayonneAudio *au, Audio::Info *inf, const char *d, const char **list) :
 ScriptThread(interp, 0)
 {
 	memcpy(&to, inf, sizeof(to));
@@ -31,6 +31,7 @@ ScriptThread(interp, 0)
 	lbuffer = NULL;
 	paths = list;
 	completed = false;
+	dest = setString(destname, sizeof(destname), d);
 }
 
 BuildThread::~BuildThread()
@@ -62,14 +63,7 @@ BuildThread::~BuildThread()
 
 void BuildThread::run(void)
 {
-	const char *fn = *(paths++);
-
-	fn = in->getFilename(fn, true);
-	if(!fn)
-		exit("unable-to-access");
-
-	setString(pathname, sizeof(pathname), fn);
-	fn = pathname;
+	const char *fn = dest;
 
 	remove(fn);
 	out.create(fn, &to, false, to.framing);
@@ -173,8 +167,8 @@ void BuildThread::copyConvert(void)
 CopyThread::CopyThread(ScriptInterp *interp, const char *from, const char *to) :
 ScriptThread(interp, 0)
 {
-	src = from;
-	dest = to;
+	src = setString(fn1, sizeof(fn1), from);
+	dest = setString(fn2, sizeof(fn2), to);
 	in = NULL;
 	out = NULL;
 }
