@@ -1,4 +1,4 @@
-#!/bin/sh
+#!../../utils/btsexec
 #bayonne: echo "*** BAYONNE LIBEXEC SHELL STARTUP ***"
 #
 # Copyright (C) 2005 Open Source Telecom Corp.
@@ -27,19 +27,21 @@ echo "*** LIBEXEC DIR $prefix" >&2
 echo "*** LIBEXEC SCR $SERVER_SCRIPTS" >&2
 echo "*** LIBEXEC SYS $SERVER_SYSEXEC" >&2
 
+echo "*** PIN ARGUMENT PASSED IN ENV $ARGS_PIN" >&2
+
 # issue head command using session id and report server headers
 echo "$PORT_TSESSION head"
-../testexec
+../../utils/testexec
 
 # issue args command for retrieving libexec command line arguments (if any)
 echo "$PORT_TSESSION args"
-../testexec
+../../utils/testexec
 
 # play a phrase through phrasebook using the default server voice settings
 # and return transactional results
 echo "$PORT_TSESSION prompt &number 123"
-../testexec
+../../utils/testexec
 
 # catch the exit message at timeout and show it
-../testexec
+../../utils/testexec
 
